==> enterprisemodules-db2_config-0.1.3.tar.gz: enterprisemodules-db2_config-0.1.3/lib/puppet/type/db2_schema.rb <==
# frozen_string_literal: true

#
#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift(File.absolute_path("#{__dir__}/../.."))
$LOAD_PATH.unshift(File.absolute_path("#{__dir__}/../../../../easy_type/lib"))
require 'easy_type'
require 'puppet_x/enterprisemodules/db2/core'

Puppet::Type.newtype(:db2_schema) do
  include EasyType
  include PuppetX::EnterpriseModules::Db2::Type
  include PuppetX::EnterpriseModules::Db2::Access
  include PuppetX::EnterpriseModules::Db2::Commands

  desc <<-DESC
  This resource allows you to manage a DB2 schema. Here is an example on how to use this:

      db2_schema { 'db2inst1/MYDB/MY_SCHEMA':
        ensure      => 'present',
      }

  This will create the schema `MY_SCHEMA` in the database `MYDB` on instance `db2inst1`.
  DESC

  to_get_raw_resources do
    schemas = []
    db2_instance_names.each do |instance|
      databases_names_on(instance).each do |database|
        schemas += schemas_on(instance, database).collect { |e| e.merge(:instance => instance, :database => database) }
      end
    end
    schemas
  end

  ensurable

  on_create do
    [:db2, "create schema #{schema_name}", { :instance => instance_name, :database => database_name }]
  end

  on_modify do
    [:db2, "alter schema #{schema_name}", { :instance => instance_name, :database => database_name, :skip_without_properties => true }]
  end

  on_destroy do
    [:db2, "drop schema #{schema_name} restrict", { :instance => instance_name, :database => database_name }]
  end

  map_titles_to_attributes([%r{((.*)/(.*)/(.*))}, [:name, :instance_name, :database_name, :schema_name]])

  parameter :name
  parameter :instance_name
  parameter :database_name
  parameter :schema_name

  property  :owner
  property  :datacapture
  property  :remarks
end

==> enterprisemodules-db2_config-0.3.0.tar.gz: enterprisemodules-db2_config-0.3.0/lib/puppet/type/db2_schema.rb <==
# frozen_string_literal: true

#
#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift(File.absolute_path("#{__dir__}/../.."))
$LOAD_PATH.unshift(File.absolute_path("#{__dir__}/../../../../easy_type/lib"))
require 'easy_type'
require 'puppet_x/enterprisemodules/db2/core'

Puppet::Type.newtype(:db2_schema) do
  include EasyType
  include PuppetX::EnterpriseModules::Db2::Type
  include PuppetX::EnterpriseModules::Db2::Access
  include PuppetX::EnterpriseModules::Db2::Commands

  desc <<-DESC
  This resource allows you to manage a DB2 schema. Here is an example on how to use this:

      db2_schema { 'db2inst1/MYDB/MY_SCHEMA':
        ensure      => 'present',
      }

  This will create the schema `MY_SCHEMA` in the database `MYDB` on instance `db2inst1`.
  DESC

  to_get_raw_resources do
    schemas = []
    db2_instance_names.each do |instance|
      primary_database_names_on(instance).each do |database|
        schemas += schemas_on(instance, database).collect { |e| e.merge(:instance => instance, :database => database) }
      end
    end
    schemas
  end

  ensurable

  on_create do
    [:db2, "create schema #{schema_name}", { :instance => instance_name, :database => database_name }]
  end

  on_modify do
    [:db2, "alter schema #{schema_name}", { :instance => instance_name, :database => database_name, :skip_without_properties => true }]
  end

  on_destroy do
    [:db2, "drop schema #{schema_name} restrict", { :instance => instance_name, :database => database_name }]
  end

  map_titles_to_attributes([%r{((.*)/(.*)/(.*))}, [:name, :instance_name, :database_name, :schema_name]])

  parameter :name
  parameter :instance_name
  parameter :database_name
  parameter :schema_name

  property  :owner
  property  :datacapture
  property  :remarks
end
